@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   MenuLibre - Advanced fd.o Compliant Menu Editor
-#   Copyright (C) 2012-2018 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2019 Sean Davis <smd.seandavis@gmail.com>
 #   Copyright (C) 2016-2018 OmegaPhil <OmegaPhil@startmail.com>
 #
 #   This program is free software: you can redistribute it and/or modify it
@@ -1550,7 +1550,7 @@ class MenulibreWindow(Gtk.ApplicationWindow):
 
             button.set_tooltip_markup(tooltip)
             entry.set_text(value)
-            label.set_label(markup)
+            label.set_markup(markup)
 
         # Filename, Actions, Categories, and Icon have their own functions.
         elif key == 'Filename':
