@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   MenuLibre - Advanced fd.o Compliant Menu Editor
-#   Copyright (C) 2012-2018 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2019 Sean Davis <smd.seandavis@gmail.com>
 #   Copyright (C) 2017-2018 OmegaPhil <OmegaPhil@startmail.com>
 #
 #   This program is free software: you can redistribute it and/or modify it
@@ -96,7 +96,7 @@ def getRelatedKeys(menu_item_type, key_only=False):
 def escapeText(text):
     if text is None:
         return ""
-    return GLib.markup_escape_text(text, len(text))
+    return GLib.markup_escape_text(text)
 
 
 def getProcessUsername(process):
@@ -564,7 +564,7 @@ def determine_bad_desktop_files():
     # stderr is returned as bytes, so converting it to the line-buffered output
     # I actually want
     bad_desktop_files = []
-    for line in result.stderr.decode().split('\n'):
+    for line in result.stderr.decode('UTF-8').split('\n'):
         matches = re.match(r'^Failed to load "(.+\.desktop)"$', line)
         if matches:
             desktop_file = matches.groups()[0]
@@ -671,7 +671,7 @@ def validate_desktop_file(desktop_file):  # noqa
         exec_key = keyfile.get_string(start_group,
                                       GLib.KEY_FILE_DESKTOP_KEY_EXEC)
     except GLib.Error:
-        return _('%s key not found') % 'Exec'
+        return False # LP: #1788814, Exec key is not required
 
     try:
         if find_program(exec_key) is None:
